Citation — turbo-turtle 1.2.5 documentation

Skip to main content
`Ctrl`+`K`

# Citation

The preferred citations can be found in the CITATION file in the project root repository. The contents of this file are included below for reference.

     1# General with "All versions" Zenodo
     2@misc{turbo-turtle-software,
     3  title        = {{turbo-turtle}},
     4  author       = {Brindley, Kyle and Roberts, Thomas},
     5  doi          = {10.5281/zenodo.13787498},
     6  organization = {Los Alamos National Laboratory},
     7  address      = {Los Alamos, New Mexico, USA},
     8  license      = {BSD 3-Clause},
     9  url          = {https://github.com/lanl-aea/turbo-turtle},
    10  year         = {2025}
    11}
    12# Current with "All versions" Zenodo
    13@misc{turbo-turtle-1-2-6,
    14  title        = {{turbo-turtle} 1.2.6},
    15  author       = {Brindley, Kyle and Roberts, Thomas},
    16  doi          = {10.5281/zenodo.13787498},
    17  organization = {Los Alamos National Laboratory},
    18  address      = {Los Alamos, New Mexico, USA},
    19  license      = {BSD 3-Clause},
    20  url          = {https://github.com/lanl-aea/turbo-turtle},
    21  year         = {2025}
    22}
    23# Most up-to-date Zenodo
    24@misc{turbo-turtle-1-1-5,
    25  title        = {{turbo-turtle} 1.1.5},
    26  author       = {Brindley, Kyle and Roberts, Thomas},
    27  doi          = {10.5281/zenodo.15115383},
    28  organization = {Los Alamos National Laboratory},
    29  address      = {Los Alamos, New Mexico, USA},
    30  license      = {BSD 3-Clause},
    31  url          = {https://github.com/lanl-aea/turbo-turtle},
    32  year         = {2025}
    33}